@@ -192,30 +192,6 @@
 
 #define SOUND_BELL "$"
 
-#define ICS_LOGON "ICS.ini"
-#define SETTINGS_FILE "WinBoard.ini"
-
-#define ICS_NAMES \
-  "chessclub.com /icsport=5000 /icshelper=timestamp\n" \
-  "freechess.org /icsport=5000 /icshelper=timeseal\n" \
-  "eics.daimi.aau.dk /icsport=5000 /icshelper=timeseal\n" \
-  "primrose.warwick.ac.uk /icsport=5000 /icshelper=timeseal\n" \
-  "fly.cc.fer.hr /icsport=7890\n" \
-  "dics.dds.nl /icsport=5000 /icshelper=timeseal\n" \
-  "chess.eerie.fr /icsport=5000 /icshelper=timeseal\n" \
-  "chess.etud.insa-tlse.fr /icsport=5000 /icshelper=timeseal\n" \
-  "chess.unix-ag.uni-kl.de /icsport=5000 /icshelper=timeseal\n" \
-  "chess.mds.mdh.se /icsport=5555 /icshelper=timeseal\n" \
-  "chess.mds.mdh.se /icsport=5000\n" \
-  "vics.ver.ucc.mx /icsport=5000\n" \
-  "ics.interdomain.net.au /icsport=5000\n" \
-  "fics.infcom.it /icsport=5000\n" \
-  "chess.isholf.is /icsport=5000 /icshelper=timeseal\n" \
-  "chess-server.spidernet.com.cy /icsport=5000 /icshelper=timeseal\n" \
-  "queen.chessclub.com /icsport=5000 /icshelper=timestamp\n" \
-  "rook.chessclub.com /icsport=5000 /icshelper=timestamp\n" \
-  "chess.net /icsport=5000\n"
-
 #define BUILT_IN_SOUND_NAMES {\
   "Beepbeep", "Ching", "Click", "Cymbal", "Ding", "Drip", \
   "Gong", "Laser", "Move", "Penalty", "Phone", "Pop", "Pop2", \
@@ -225,33 +201,52 @@
   "Win", NULL \
 }
 
-#define ICS_TEXT_MENU_DEFAULT \
-  "-\n" \
-  "&Who,who,0,1\n" \
-  "Playe&rs,players,0,1\n" \
-  "&Games,games,0,1\n" \
-  "&Sought,sought,0,1\n" \
-  "|&Tell (name),tell,1,0\n" \
-  "M&essage (name),message,1,0\n" \
-  "-\n" \
-  "&Finger (name),finger,1,1\n" \
-  "&Vars (name),vars,1,1\n" \
-  "&Observe (name),observe,1,1\n" \
-  "&Match (name),match,1,1\n" \
-  "Pl&ay (name),play,1,1\n"
+#define SETTINGS_FILE         "winboard.ini"
 
-#if 0
-#define FCP_NAMES \
-  "GNUChess\n" \
-  "WCrafty /fd=\"C:\\Program Files\\Crafty\"\n"
-#define SCP_NAMES \
-  "GNUChess\n" \
-  "WCrafty /sd=\"C:\\Program Files\\Crafty\"\n"
-#else
-#define FCP_NAMES \
-  "GNUChess\n" \
-  "\"GNUChes5 xboard\"\n"
-#define SCP_NAMES \
-  "GNUChess\n" \
-  "\"GNUChes5 xboard\"\n"
-#endif
+#define ICS_LOGON             "ics.ini"
+
+#define ICS_NAMES "\
+chessclub.com /icsport=5000 /icshelper=timestamp\n\
+freechess.org /icsport=5000 /icshelper=timeseal\n\
+server.uschesslive.org /icsport=5000 /icshelper=timeseal\n\
+europe.freechess.org /icsport=5000 /icshelper=timeseal\n\
+primrose.warwick.ac.uk /icsport=5000 /icshelper=timeseal\n\
+fly.cc.fer.hr /icsport=7890\n\
+dics.dds.nl /icsport=5000 /icshelper=timeseal\n\
+chess.unix-ag.uni-kl.de /icsport=5000 /icshelper=timeseal\n\
+chess.mds.mdh.se /icsport=5555 /icshelper=timeseal\n\
+chess.mds.mdh.se /icsport=5000\n\
+vics.ver.ucc.mx /icsport=5000\n\
+zics.org /icsport=5000\n\
+chess-server.spidernet.com.cy /icsport=5000 /icshelper=timeseal\n\
+ajedrez.cec.uchile.cl /icsport=5000\n\
+jogo.cex.org.br /icsport=5000\n\
+queen.chessclub.com /icsport=5000 /icshelper=timestamp\n\
+chess.net /icsport=5000\n\
+"
+
+#define ICS_TEXT_MENU_DEFAULT "\
+-\n\
+&Who,who,0,1\n\
+Playe&rs,players,0,1\n\
+&Games,games,0,1\n\
+&Sought,sought,0,1\n\
+|&Tell (name),tell,1,0\n\
+M&essage (name),message,1,0\n\
+-\n\
+&Finger (name),finger,1,1\n\
+&Vars (name),vars,1,1\n\
+&Observe (name),observe,1,1\n\
+&Match (name),match,1,1\n\
+Pl&ay (name),play,1,1\n\
+"
+
+#define FCP_NAMES "\
+GNUChess\n\
+\"GNUChes5 xboard\"\n\
+"
+
+#define SCP_NAMES "\
+GNUChess\n\
+\"GNUChes5 xboard\"\n\
+"
